package test.entity;

import entity.Ausdruecke;
import java.util.regex.Pattern;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

public class AusdrueckeTest {
    
    private Ausdruecke aus;
    
    @BeforeEach
    public void setUp(){
        this. aus = new Ausdruecke();
    }
    
    private void istOk(String aufgabe, String reg, String text){
        Assertions.assertTrue(Pattern.matches(reg, text)
            , aufgabe + ": \"" + text +"\" muss erlaubt sein");
    }
    
    private void istNichtOk(String aufgabe, String reg, String text){
        Assertions.assertFalse(Pattern.matches(reg, text)
            , aufgabe + ": \"" + text +"\" darf nicht erlaubt sein");
    }
    
    @Test
    public void testa1(){
        istOk("a", aus.a(), "Erfolg");
    }
    
    @Test
    public void testa2(){
        istOk("a", aus.a(), " kein Erfolg!");
    }
 
    @Test
    public void testa3(){
        istOk("a", aus.a(), "Erfolgslosigkeit");
    }   

    @Test
    public void testa4(){
        istNichtOk("a", aus.a(), "");
    }     
    
    @Test
    public void testa5(){
        istNichtOk("a", aus.a(), "besonders erfolgreich");
    }
    
    @Test
    public void testb1(){
        istOk("b", aus.b(), "erfolg");
    }
    
    @Test
    public void testb2(){
        istOk("b", aus.b(), " kein Erfolg oder doch erfolgreich!");
    }
 
    @Test
    public void testb3(){
        istOk("b", aus.b(), "echt erfolgslos");
    }   

    @Test
    public void testb4(){
        istNichtOk("b", aus.b(), "");
    }     
    
    @Test
    public void testb5(){
        istNichtOk("b", aus.b(), "ERFOLG eRfOlG");
    }    
    
    @Test
    public void testc1(){
        istOk("c", aus.c(), "aaa");
    }
    
    @Test
    public void testc2(){
        istOk("c", aus.c(), " Bahamas Bananas");
    }
 
    @Test
    public void testc3(){
        istOk("c", aus.c(), "Saalbau");
    }   

    @Test
    public void testc4(){
        istNichtOk("c", aus.c(), "");
    }     
    
    @Test
    public void testc5(){
        istNichtOk("c", aus.c(), "aa");
    } 
    
    @Test
    public void testc6(){
        istNichtOk("c", aus.c(), "Hasennase");
    }
    
    @Test
    public void testd1(){
        istOk("d", aus.d(), "0000x9999");
    }
    
    @Test
    public void testd2(){
        istOk("d", aus.d(), " erst 1234 und dann 4242, jo.");
    }
 
    @Test
    public void testd3(){
        istOk("d", aus.d(), "___9999_3333____");
    }   

    @Test
    public void testd4(){
        istNichtOk("d", aus.d(), "12345678");
    }     
    
    @Test
    public void testd5(){
        istNichtOk("d", aus.d(), "12345 ist zu lang, 9999 nicht");
    } 
    
    @Test
    public void testd6(){
        istNichtOk("d", aus.d(), "123 ist zu kurz, 1111 nicht");
    }   
    
    @Test
    public void teste1(){
        istOk("e", aus.e(), "08.02.2016");
    }
    
    @Test
    public void teste2(){
        istOk("e", aus.e(), "geht leider auch 42.58.0");
    }
 
    @Test
    public void teste3(){
        istOk("e", aus.e(), "19.1.2038 UNIX endet");
    }   

    @Test
    public void teste4(){
        istNichtOk("e", aus.e(), "1.1.80 oder 2.1.80");
    }     
    
    @Test
    public void teste5(){
        istNichtOk("e", aus.e(), "Unix endet am 19.1.2038 um 3:14:08");
    } 
    
    @Test
    public void teste6(){
        istNichtOk("e", aus.e(), "welcher Tag ist der 1.1.10000?");
    }     
    
    @Test
    public void testf1(){
        istOk("f", aus.f(), "Bananenboot");
    }
    
    @Test
    public void testf2(){
        istOk("f", aus.f(), " ao tinky winky ao");
    }
 
    @Test
    public void testf3(){
        istOk("f", aus.f(), "Hausbootsanleger");
    }

    @Test
    public void testf4(){
        istOk("f", aus.f(), "oha Kakao");
    }
    
    @Test
    public void testf5(){
        istOk("f", aus.f(), " Hossa holla ein Whiskey");
    }
 
    @Test
    public void testf6(){
        istOk("f", aus.f(), "Boom Shakalak");
    }

    @Test
    public void testf7(){
        istNichtOk("f", aus.f(), "Beatbox Hool");
    }

    @Test
    public void testf8(){
        istNichtOk("f", aus.f(), "Kantatenhoerer");
    }

    @Test
    public void testf9(){
        istNichtOk("f", aus.f(), "Haus Kunterbunt");
    }    
}
